# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"PathStr": "51_pdf_utils.ipynb",
         "PathURL": "10_utils.ipynb",
         "logger": "10_utils.ipynb",
         "check_img": "10_utils.ipynb",
         "clean_error_img": "10_utils.ipynb",
         "hush": "10_utils.ipynb",
         "static_root": "10_utils.ipynb",
         "STATIC": "10_utils.ipynb",
         "friendly_size": "10_utils.ipynb",
         "ls": "10_utils.ipynb",
         "gv": "10_utils.ipynb",
         "get_url_size": "10_utils.ipynb",
         "download": "10_utils.ipynb",
         "url_2_text": "10_utils.ipynb",
         "download_and_unpack": "10_utils.ipynb",
         "unpack_archive": "10_utils.ipynb",
         "read_csv_from_zip": "10_utils.ipynb",
         "BugBook": "12_bug.ipynb",
         "module_not_found_message1": "12_bug.ipynb",
         "module_not_found_message2": "12_bug.ipynb",
         "module_not_found_error_filter": "12_bug.ipynb",
         "BUGBOOK": "12_bug.ipynb",
         "render_download_button": "12_bug.ipynb",
         "custom_exc": "12_bug.ipynb",
         "itb": "12_bug.ipynb",
         "CosineSearch": "15_interp_latent.ipynb",
         "InterpEmbeddings": "15_interp_latent.ipynb",
         "IMAGENET_CLASSES": "16_interp_cnn.ipynb",
         "IMAGENET_MEAN": "16_interp_cnn.ipynb",
         "IMAGENET_STD": "16_interp_cnn.ipynb",
         "simple_to_tensor": "16_interp_cnn.ipynb",
         "basic_trans": "16_interp_cnn.ipynb",
         "tensor_to_8b": "16_interp_cnn.ipynb",
         "get_features_resnet": "16_interp_cnn.ipynb",
         "plot_contrary_overlap": "16_interp_cnn.ipynb",
         "visualize_conv_backbone": "16_interp_cnn.ipynb",
         "image_upload": "16_interp_cnn.ipynb",
         "upload_and_visualize_cnn": "16_interp_cnn.ipynb",
         "ImageLabeler": "20_Image_Labeler.ipynb",
         "SingleClassImageLabeler": "20_Image_Labeler.ipynb",
         "MultiClassImageLabeler": "20_Image_Labeler.ipynb",
         "no_missing_values": "35_tabular_data.ipynb",
         "plot_hist": "35_tabular_data.ipynb",
         "plot_feat_correlations": "35_tabular_data.ipynb",
         "plot_feat_dendrogram": "35_tabular_data.ipynb",
         "keyerror_in_tabular": "39_tabular.ipynb",
         "Textual": "41_nlp_data.ipynb",
         "HFTextBlock": "41_nlp_data.ipynb",
         "InterpEmbeddingsTokenizer": "45_nlp_interp.ipynb",
         "TextualPDF": "51_pdf_utils.ipynb"}

modules = ["utils.py",
           "bug.py",
           "interp/latent.py",
           "interp/vision.py",
           "interp/__init__.py",
           "turk/image.py",
           "tabular/data.py",
           "tabular/__init__.py",
           "nlp/data.py",
           "nlp/interp.py",
           "nlp/__init__.py",
           "pdf.py"]

doc_url = "https://unpackai.github.io/unpackai/"

git_url = "https://github.com/unpackai/unpackai/tree/master/"

def custom_doc_links(name): return None
